@@ -1,17 +1,14 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import unicode_literals
 import re
 
 from django.core.validators import RegexValidator
 from django.db import models
 from django.db.models import signals
-from django.utils.encoding import python_2_unicode_compatible
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
 
 from .bbcode import get_parser
 
+
 __all__ = (
     'BBCodeContent',
     'BBCodeTextField',
@@ -22,10 +19,12 @@ __all__ = (
 _rendered_content_field_name = lambda name: '_{}_rendered'.format(name)
 
 _smiley_code_re = re.compile(r'^[\w|\S]+$')
-validate_smiley_code = RegexValidator(_smiley_code_re, _("Enter a valid 'smiley code' consisting of any character without whitespace characters"), 'invalid')
+validate_smiley_code = RegexValidator(
+    _smiley_code_re,
+    _("Enter a valid 'smiley code' consisting of any character without whitespace characters"),
+    'invalid')
 
 
-@python_2_unicode_compatible
 class BBCodeContent(object):
     def __init__(self, raw, rendered=None):
         self.raw = raw
@@ -37,11 +36,12 @@ class BBCodeContent(object):
 
 class BBCodeTextCreator(object):
     """
-    Acts as the Django's default attribute descriptor class (enabled via the SubfieldBase metaclass).
-    The main difference is that it does not call to_python() on the BBCodeTextField class. Instead, it
-    stores the two different values of a BBCode content (the raw and the rendered data) separately.
-    These values can be separately updated when something is assigned. When the field is accessed,
-    a BBCodeContent instance will be returned ; this one is built with the current data.
+    Acts as the Django's default attribute descriptor class (enabled via the SubfieldBase
+    metaclass). The main difference is that it does not call to_python() on the BBCodeTextField
+    class. Instead, it stores the two different values of a BBCode content (the raw and the rendered
+    data) separately. These values can be separately updated when something is assigned. When the
+    field is accessed, a BBCodeContent instance will be returned ; this one is built with the
+    current data.
     """
     def __init__(self, field):
         self.field = field
@@ -68,23 +68,23 @@ class BBCodeTextCreator(object):
 class BBCodeTextField(models.TextField):
     """
     A BBCode text field contributes two columns to the model instead of the standard single column.
-    The initial column stores the BBCode content and the other one keeps the rendered content returned
-    by the BBCode parser.
+    The initial column stores the BBCode content and the other one keeps the rendered content
+    returned by the BBCode parser.
     """
     def __init__(self, *args, **kwargs):
-        # For South FakeORM / Django 1.7 migration serializer compatibility: the frozen version of a
-        # BBCodeTextField can't try to add a '*_rendered' field, because the '*_rendered' field itself
-        # is frozen / serialized as well.
+        # For Django 1.7 migration serializer compatibility: the frozen version of a
+        # BBCodeTextField can't try to add a '*_rendered' field, because the '*_rendered' field
+        # itself is frozen / serialized as well.
         self.add_rendered_field = not kwargs.pop('no_rendered_field', False)
         super(BBCodeTextField, self).__init__(*args, **kwargs)
 
     def deconstruct(self):
         """
-        As outlined in the Django 1.7 documentation, this method tells Django how to take an instance
-        of a new field in order to reduce it to a serialized form. This can be used to configure what
-        arguments need to be passed to the __init__() method of the field in order to re-create it.
-        We use it in order to pass the 'no_rendered_field' to the __init__() method. This will allow
-        the _rendered field to not be added to the model class twice.
+        As outlined in the Django 1.7 documentation, this method tells Django how to take an
+        instance of a new field in order to reduce it to a serialized form. This can be used to
+        configure what arguments need to be passed to the __init__() method of the field in order to
+        re-create it. We use it in order to pass the 'no_rendered_field' to the __init__() method.
+        This will allow the _rendered field to not be added to the model class twice.
         """
         name, import_path, args, kwargs = super(BBCodeTextField, self).deconstruct()
         kwargs['no_rendered_field'] = True
@@ -145,23 +145,3 @@ class SmileyCodeField(models.CharField):
         if 'db_index' not in kwargs:
             kwargs['db_index'] = True
         super(SmileyCodeField, self).__init__(*args, **kwargs)
-
-
-# Allow South to handle those fields smoothly
-try:
-    from south.modelsinspector import add_introspection_rules
-
-    # For a normal BBCodeTextField, the add_rendered_field attribute is always True,
-    # which means that the no_rendered_field arg will always be True in a frozen BBCodeTextField,
-    # which is what we want. The use of this flag will tell South not to make the _rendered
-    # fields again.
-    add_introspection_rules(rules=[((BBCodeTextField,),
-                                    [],
-                                    {'no_rendered_field': ('add_rendered_field',
-                                                           {})})],
-                            patterns=['precise_bbcode\.fields\.BBCodeTextField'])
-
-    # SmileyCodeField
-    add_introspection_rules([], ['^precise_bbcode\.fields\.SmileyCodeField'])
-except ImportError:  # pragma: no cover
-    pass
